@@ -12,6 +12,8 @@ import fire
 import platform
 import sys
 
+from nexinfosys.models.musiasem_methodology_support import find_max_recursion
+
 print(f"Executable: {sys.executable}; V: {sys.version}; {platform.python_build()}; CONDA_PREFIX: {os.getenv('CONDA_PREFIX')}")
 
 from nexinfosys.command_generators import Issue, IType
@@ -120,7 +122,6 @@ def prepare_base_state(base_url: str, solve: bool, directory: str = None, force_
                 any_error = True
         # Write if there are no errors
         if not any_error:
-            # raise Exception(f'There were errors with the NIS base file {base_url}.')
             from nexinfosys.serialization import serialize_state
             state = nis.get_state()
             serial_state = serialize_state(state)
@@ -129,6 +130,11 @@ def prepare_base_state(base_url: str, solve: bool, directory: str = None, force_
                 f.write(hash_)
             with open(state_file, "wb") as f:
                 f.write(serial_state)
+        else:
+            # raise Exception(f'There were errors with the NIS base file {base_url}.')
+            # print_issues("NIS base preparation", f_name, issues, "NIS base preparation failed, check errors")
+            state = None
+            serial_state = None
     else:
         issues = None  # Cached, no issues
         with open(state_file, "rb") as f:
@@ -138,31 +144,60 @@ def prepare_base_state(base_url: str, solve: bool, directory: str = None, force_
     return state, serial_state, issues
 
 
-def print_issues(operation, file, issues: List[Issue]):
+class PrintColors:
+    PURPLE = '\033[95m'
+    CYAN = '\033[96m'
+    DARKCYAN = '\033[36m'
+    BLUE = '\033[94m'
+    GREEN = '\033[92m'
+    YELLOW = '\033[93m'
+    RED = '\033[91m'
+    BOLD = '\033[1m'
+    UNDERLINE = '\033[4m'
+    END = '\033[0m'
+
+
+def print_issues(operation, file, issues: List[Issue], msg_in_case_of_error: str = None):
     if issues is not None:
-        if len(issues) > 0:
-            error_count = 0
-            warning_count = 0
+        # First print all the issues
+        w = len(str(len(issues)))
+        i = 0
+        max_of_a_type = 1000
+        for issue_type in [IType.ERROR, IType.WARNING]:
+            j = 0
             for issue in issues:
-                if issue.itype == IType.ERROR:
-                    error_count += 1
-            if error_count > 0:
-                print(f"There was a total of {error_count} errors detected")
+                if issue.itype == issue_type:
+                    i += 1
+                    j += 1
+                    s = f'{issue.itype.name:7}: {issue.description} ({issue.ctype}, {issue.location})'  # f"{issue.itype.name:7}: {issue.description}"
+                    print(f"{i:{w}}: {s}")
+                    if j > max_of_a_type:
+                        print(f"{PrintColors.YELLOW}There are more than {max_of_a_type} issues of type {issue_type.name} than allowed.{PrintColors.END}")
+                        break
+        # Finally, summary: # errors and warnings
+        errors = 0
+        warnings = 0
+        for issue in issues:
+            if issue.itype == IType.ERROR:
+                errors += 1
+            elif issue.itype == IType.WARNING:
+                warnings += 1
+
+        if warnings or errors:
+            print("-------------------------------------------------------")
+
+        if warnings > 0:
+            print(f"{PrintColors.YELLOW}{warnings} warning{'s' if warnings != 1 else ''} found{PrintColors.END}")
+        if errors > 0:
+            if msg_in_case_of_error:
+                print(msg_in_case_of_error)
+            print(f"{PrintColors.RED}{errors} error{'s' if errors != 1 else ''} found{PrintColors.END}")
+
+        if errors == 0:
+            if operation:
+                print(f"{PrintColors.GREEN}{operation} successful{PrintColors.END} (no errors detected)")
             else:
-                print(f"{operation} successful (no errors detected)")
-            if warning_count > 0:
-                print(f"There was a total of {warning_count} warnings")
-            print("--------------------")
-            for issue_type in [IType.ERROR, IType.WARNING]:
-                if issue_type == IType.ERROR:
-                    print(f"Errors ({error_count} total):")
-                elif issue_type == IType.WARNING:
-                    print(f"Warnings ({warning_count} total):")
-                for issue in issues:
-                    if issue.itype == issue_type:
-                        print(issue_str(issue))
-        else:
-            print(f"{operation} successful, and no issues!")
+                print(f"{PrintColors.GREEN}Operation finished successfully{PrintColors.END} (no errors detected)")
     else:
         print(
             f"File '{file}' was already cached, meaning no change and no errors detected. "
@@ -321,6 +356,9 @@ nexinfosys solve https://docs.google.com/spreadsheets/d/1C5xNGvdORWqrWL6Ux2nBXMd
                 issues = nis.recalculate(params)
                 write_results(nis, work_path, datasets)
 
+    def find_recursion_limit(self):
+        find_max_recursion()
+
 
 def main():
     os.environ["PAGER"] = "cat" if platform.system().lower() != "windows" else "-"
