@@ -16,6 +16,9 @@ Persistent store, in database
 """
 import datetime
 import logging
+import threading
+import traceback
+from queue import Queue
 
 from sqlalchemy import Column, Boolean, Integer, String, Unicode, DateTime, LargeBinary, ForeignKey
 from copy import deepcopy
@@ -79,20 +82,50 @@ class GUID(TypeDecorator):
             return uuid.UUID(value)
 
 
-def serialize_from_object(obj):
+def exec_highly_recursive_function(func, params, size=20000):
+
     tmp = sys.getrecursionlimit()
-    sys.setrecursionlimit(10000)
-    tmp_str = jsonpickle.encode(obj)  # .encode("ascii")
+    tmp2 = threading.stack_size()
+    sys.setrecursionlimit(size)
+    threading.stack_size(0x1000000)
+    que = Queue()
+    try:
+        t = threading.Thread(target=lambda q, arg1: q.put(func(arg1)), args=(que, params))
+        t.start()
+        t.join()
+    except:
+        traceback.print_exc()
+    threading.stack_size(tmp2)
     sys.setrecursionlimit(tmp)
+    return que.get()
+
+
+def serialize_from_object(obj):
+    def encode(o_):
+        return jsonpickle.encode(o_)
+
+    # tmp = sys.getrecursionlimit()
+    # sys.setrecursionlimit(10000)
+    # tmp_str = jsonpickle.encode(obj)
+    # sys.setrecursionlimit(tmp)
+    # return tmp_str
+
+    tmp_str = exec_highly_recursive_function(encode, obj)
     return tmp_str
 
 
 def deserialize_to_object(s):
-    tmp = sys.getrecursionlimit()
-    sys.setrecursionlimit(10000)
-    tmp_str = jsonpickle.decode(s)
-    sys.setrecursionlimit(tmp)
-    return tmp_str
+    def decode(s_):
+        return jsonpickle.decode(s_)
+
+    # tmp = sys.getrecursionlimit()
+    # sys.setrecursionlimit(10000)
+    # tmp_str = decode(s)
+    # sys.setrecursionlimit(tmp)
+    # return tmp_str
+
+    tmp_obj = exec_highly_recursive_function(decode, s)
+    return tmp_obj
 
 
 class BaseMixin(object):
@@ -544,3 +577,116 @@ def load_table(sf, clazz, d):
             session.add(ins)
     session.commit()
     sf.remove()
+
+
+import sys
+import itertools
+
+
+class RecursiveBlowup1:
+    def __init__(self):
+        self.__init__()
+
+
+def test_init():
+    return RecursiveBlowup1()
+
+
+class RecursiveBlowup2:
+    def __repr__(self):
+        return repr(self)
+
+
+def test_repr():
+    return repr(RecursiveBlowup2())
+
+
+class RecursiveBlowup4:
+    def __add__(self, x):
+        return x + self
+
+
+def test_add():
+    return RecursiveBlowup4() + RecursiveBlowup4()
+
+
+class RecursiveBlowup5:
+    def __getattr__(self, attr):
+        return getattr(self, attr)
+
+
+def test_getattr():
+    return RecursiveBlowup5().attr
+
+
+class RecursiveBlowup6:
+    def __getitem__(self, item):
+        return self[item - 2] + self[item - 1]
+
+
+def test_getitem():
+    return RecursiveBlowup6()[5]
+
+
+def test_recurse():
+    return test_recurse()
+
+
+def test_cpickle(_cache={}):
+    import io
+    try:
+        import _pickle
+    except ImportError:
+        print("cannot import _pickle, skipped!")
+        return
+    k, l = None, None
+    for n in itertools.count():
+        try:
+            l = _cache[n]
+            continue  # Already tried and it works, let's save some time
+        except KeyError:
+            for i in range(100):
+                l = [k, l]
+                k = {i: l}
+        _pickle.Pickler(io.BytesIO(), protocol=-1).dump(l)
+        _cache[n] = l
+
+
+def test_compiler_recursion():
+    # The compiler uses a scaling factor to support additional levels
+    # of recursion. This is a sanity check of that scaling to ensure
+    # it still raises RecursionError even at higher recursion limits
+    compile("()" * (10 * sys.getrecursionlimit()), "<single>", "single")
+
+
+def check_limit(n, test_func_name):
+    sys.setrecursionlimit(n)
+    if test_func_name.startswith("test_"):
+        print(test_func_name[5:])
+    else:
+        print(test_func_name)
+    test_func = globals()[test_func_name]
+    try:
+        test_func()
+    # AttributeError can be raised because of the way e.g. PyDict_GetItem()
+    # silences all exceptions and returns NULL, which is usually interpreted
+    # as "missing attribute".
+    except (RecursionError, AttributeError):
+        pass
+    else:
+        print("Yikes!")
+
+
+def find_max_recursion():
+    limit = 1000
+    while 1:
+        check_limit(limit, "test_recurse")
+        check_limit(limit, "test_add")
+        check_limit(limit, "test_repr")
+        check_limit(limit, "test_init")
+        check_limit(limit, "test_getattr")
+        check_limit(limit, "test_getitem")
+        check_limit(limit, "test_cpickle")
+        check_limit(limit, "test_compiler_recursion")
+        print("Limit of %d is fine" % limit)
+        limit = limit + 100
\ No newline at end of file
